@@ -390,28 +390,11 @@ g_usb_device_async_not_open_error (GUsbDevice          *device,
 	                         g_usb_device_get_pid (device));
 }
 
-/**
- * g_usb_device_open:
- * @device: a #GUsbDevice
- * @error: a #GError, or %NULL
- *
- * Opens the device for use.
- *
- * Warning: this function is synchronous.
- *
- * Return value: %TRUE on success
- *
- * Since: 0.1.0
- **/
 gboolean
-g_usb_device_open (GUsbDevice  *device,
-                   GError     **error)
+_g_usb_device_open_internal (GUsbDevice *device, GError **error)
 {
 	gint rc;
 
-	g_return_val_if_fail (G_USB_IS_DEVICE (device), FALSE);
-	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
 	if (device->priv->handle != NULL) {
 		g_set_error (error,
 			     G_USB_DEVICE_ERROR,
@@ -427,6 +410,33 @@ g_usb_device_open (GUsbDevice  *device,
 	return g_usb_device_libusb_error_to_gerror (device, rc, error);
 }
 
+/**
+ * g_usb_device_open:
+ * @device: a #GUsbDevice
+ * @error: a #GError, or %NULL
+ *
+ * Opens the device for use.
+ *
+ * Warning: this function is synchronous.
+ *
+ * Return value: %TRUE on success
+ *
+ * Since: 0.1.0
+ **/
+gboolean
+g_usb_device_open (GUsbDevice *device, GError **error)
+{
+	g_return_val_if_fail (G_USB_IS_DEVICE (device), FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+	/* ignore */
+	if (g_usb_context_get_flags (device->priv->context) & G_USB_CONTEXT_FLAGS_AUTO_OPEN_DEVICES)
+		return TRUE;
+
+	/* open */
+	return _g_usb_device_open_internal (device, error);
+}
+
 /**
  * g_usb_device_get_custom_index:
  * @device: a #GUsbDevice
@@ -608,6 +618,10 @@ g_usb_device_close (GUsbDevice  *device,
 	g_return_val_if_fail (G_USB_IS_DEVICE (device), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
+	/* ignore */
+	if (g_usb_context_get_flags (device->priv->context) & G_USB_CONTEXT_FLAGS_AUTO_OPEN_DEVICES)
+		return TRUE;
+
 	if (device->priv->handle == NULL)
 		return g_usb_device_not_open_error (device, error);
 
